@@ -3,7 +3,7 @@ from plone import api
 from plone.i18n.normalizer.interfaces import IIDNormalizer
 from Products.CMFPlone.interfaces import ISelectableConstrainTypes
 from zope.component import getUtility
-
+from uuid import uuid4
 
 TASSONOMIA_SERVIZI = [
     "Anagrafe e stato civile",
@@ -60,28 +60,39 @@ def folderSubstructureGenerator(title, types=[]):
         return
 
     tree_root = api.content.create(container=container, type="Document", title=title)
+    create_default_blocks(context=tree_root)
+
     api.content.transition(obj=tree_root, transition="publish")
     if types:
         restrict_types(context=tree_root, types=types)
 
     if title == "Servizi":
         for ts in TASSONOMIA_SERVIZI:
-            api.content.create(container=tree_root, type="Document", title=ts)
-
+            child = api.content.create(container=tree_root, type="Document", title=ts)
+            create_default_blocks(context=child)
     elif title == "Documenti e dati":
         for td in TASSONOMIA_DOCUMENTI:
-            api.content.create(container=tree_root, type="Document", title=td)
+            child = api.content.create(container=tree_root, type="Document", title=td)
+            create_default_blocks(context=child)
 
     elif title == "Novità":
         for tn in TASSONOMIA_NEWS:
-            api.content.create(container=tree_root, type="Document", title=tn)
+            child = api.content.create(container=tree_root, type="Document", title=tn)
+            create_default_blocks(context=child)
 
     elif title == "Amministrazione":
         for ta in TASSONOMIA_AMMINISTRAZIONE:
-            api.content.create(container=tree_root, type="Document", title=ta)
+            child = api.content.create(container=tree_root, type="Document", title=ta)
+            create_default_blocks(context=child)
 
 
 def restrict_types(context, types):
     constraints = ISelectableConstrainTypes(context)
     constraints.setConstrainTypesMode(1)
     constraints.setLocallyAllowedTypes(types)
+
+
+def create_default_blocks(context):
+    title_uuid = str(uuid4())
+    context.blocks = {title_uuid: {"@type": "title"}}
+    context.blocks_layout = {"items": [title_uuid]}
